Documentation
¶
Overview ¶
Package env provides utilities for environment variables.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEnvFromSystemAndConfiguration ¶
func GetEnvFromSystemAndConfiguration(cfg configuration.Configuration, userSettingsPath string, logger *zerolog.Logger) gotenv.Env
GetEnvFromSystemAndConfiguration returns the environment variables from the system and the configuration. It loads the environment variables from the shell into the current process environment After that it loads the custom config files configured in the configuration into the returned environment. The custom config files override the OS environment variables. The userSettingsPath is used to prioritize the user specified PATH over their SHELL's PATH. Config files can be specified in the configuration using the `configuration.CUSTOM_CONFIG_FILES` key.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package concurrency implements concurrency utilities
|
Package concurrency implements concurrency utilities |
|
Package constants provides constants
|
Package constants provides constants |
|
Package context implements context management for Snyk
|
Package context implements context management for Snyk |
|
Package data_structure implements data structure functionality
|
Package data_structure implements data structure functionality |
|
Package debounce implements debouncer functionality
|
Package debounce implements debouncer functionality |
|
Package delta implements delta scanning
|
Package delta implements delta scanning |
|
Package fflags implements the feature flag functionality
|
Package fflags implements the feature flag functionality |
|
Package float implements float functionality
|
Package float implements float functionality |
|
Package html implements HTML functionality for the IDE clients
|
Package html implements HTML functionality for the IDE clients |
|
Package logging implements a zerolog writer that sends log messages to the LSP server
|
Package logging implements a zerolog writer that sends log messages to the LSP server |
|
Package mcp implements MCP configure workflow call
|
Package mcp implements MCP configure workflow call |
|
Package notification implements notification functionality for Snyk
|
Package notification implements notification functionality for Snyk |
|
observability
|
|
|
error_reporting
Package error_reporting implements error reporting functionality
|
Package error_reporting implements error reporting functionality |
|
performance
Package performance implements performance instrumentation and tracing
|
Package performance implements performance instrumentation and tracing |
|
Package product contains general product names and information for Snyk product lines
|
Package product contains general product names and information for Snyk product lines |
|
Package progress implements the progress functionality
|
Package progress implements the progress functionality |
|
Package scans contains functionality related to Snyk scans
|
Package scans contains functionality related to Snyk scans |
|
Package sdk implements SDK environment handling
|
Package sdk implements SDK environment handling |
|
Package storage implements the GAF storage interface for configuration
|
Package storage implements the GAF storage interface for configuration |
|
Package storedconfig implements stored configuration functionality
|
Package storedconfig implements stored configuration functionality |
|
Package testsupport contains test helpers for Snyk
|
Package testsupport contains test helpers for Snyk |
|
Package testutil implements test setup functionality
|
Package testutil implements test setup functionality |
|
workspaceutil
Package workspaceutil provides workspace setup utilities for tests.
|
Package workspaceutil provides workspace setup utilities for tests. |
|
Package types provides commonly used types
|
Package types provides commonly used types |
|
mock_types
Package mock_types is a generated GoMock package.
|
Package mock_types is a generated GoMock package. |
|
Package uri implements URI handling for Snyk
|
Package uri implements URI handling for Snyk |
|
Package user_interface implements the user interface functionality
|
Package user_interface implements the user interface functionality |
|
Package util implements utility functions
|
Package util implements utility functions |
|
Package vcs implements VCS integration
|
Package vcs implements VCS integration |
Click to show internal directories.
Click to hide internal directories.